/**
 * A map where calling `.get()` will add a value to the map before returning it, if it does not yet exist.
 *
 * ```ts
 * const tallies = new MagicalMap<string, number>(() => 0);
 * tallies.get('joe'); // 0
 * tallies.set('fred', tallies.get('fred') + 1);
 * tallies.get('fred'); // 1
 * ```
 */
export declare class MagicalMap<Key, Value> {
    #private;
    private createNewValue;
    /**
     * @param createNewValue called when trying to `get()` for a key that is not yet in the map. The return value of `createNewValue` will be set into the map, then returned.
     */
    constructor(createNewValue: (key: Key) => Value);
    set(key: Key, value: Value): void;
    get(key: Key): Value;
    keys(): Iterable<Key>;
    values(): Iterable<Value>;
}
